pub struct Signature(pub [u8; 64]);Expand description
A 64-byte Schnorr signature.
Tuple Fields
0: [u8; 64]Trait Implementations
Sourceimpl BorshDeserialize for Signature
impl BorshDeserialize for Signature
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for Signature
impl BorshSerialize for Signature
impl Copy for Signature
Sourceimpl<'de> Deserialize<'de> for Signature
impl<'de> Deserialize<'de> for Signature
Sourcefn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
fn deserialize<D: Deserializer<'de>>(deserializer: D) -> Result<Self, D::Error>
Deserialize this value from the given Serde deserializer. Read more