pub struct VerifiedMessage {
pub zones: Vec<Zone>,
pub message: Message,
}Expand description
Result of verifying a message.
Contains the verified zones and the original message data. The message can be used to construct certificates for storage.
Fields
zones: Vec<Zone>message: MessageImplementations
Sourceimpl VerifiedMessage
impl VerifiedMessage
Sourcepub fn certificates(&self) -> CertificateIter<'_> ⓘ
pub fn certificates(&self) -> CertificateIter<'_> ⓘ
Iterate over all certificates from this verified message.
Panics if the message was not produced by Veritas::verify and
contains handle names that don’t join with their bundle’s subject —
verification guarantees every kept handle is joinable.