pub struct VerifiedMessage {
pub root_id: [u8; 32],
pub zones: Vec<Zone>,
pub message: Message,
}Expand description
Result of verifying a message.
Contains the verified zones and the original message data. The message can be used to construct certificates for storage.
Fields
root_id: [u8; 32]zones: Vec<Zone>message: MessageImplementations
Sourceimpl VerifiedMessage
impl VerifiedMessage
Sourcepub fn certificates(&self) -> CertificateIter<'_> ⓘ
pub fn certificates(&self) -> CertificateIter<'_> ⓘ
Iterate over all certificates from this verified message.